==> flowable-engine-6.1.0-sources.jar: org/flowable/engine/impl/cmd/ActivateProcessDefinitionCmd.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flowable.engine.impl.cmd;

import java.util.Date;

import org.flowable.engine.impl.jobexecutor.TimerActivateProcessDefinitionHandler;
import org.flowable.engine.impl.persistence.entity.ProcessDefinitionEntity;
import org.flowable.engine.impl.persistence.entity.SuspensionState;
import org.flowable.engine.runtime.ProcessInstance;

/**
 * @author Daniel Meyer
 * @author Joram Barrez
 */
public class ActivateProcessDefinitionCmd extends AbstractSetProcessDefinitionStateCmd {

    public ActivateProcessDefinitionCmd(ProcessDefinitionEntity processDefinitionEntity, boolean includeProcessInstances, Date executionDate, String tenantId) {
        super(processDefinitionEntity, includeProcessInstances, executionDate, tenantId);
    }

    public ActivateProcessDefinitionCmd(String processDefinitionId, String processDefinitionKey, boolean includeProcessInstances, Date executionDate, String tenantId) {
        super(processDefinitionId, processDefinitionKey, includeProcessInstances, executionDate, tenantId);
    }

    protected SuspensionState getProcessDefinitionSuspensionState() {
        return SuspensionState.ACTIVE;
    }

    protected String getDelayedExecutionJobHandlerType() {
        return TimerActivateProcessDefinitionHandler.TYPE;
    }

    protected AbstractSetProcessInstanceStateCmd getProcessInstanceChangeStateCmd(ProcessInstance processInstance) {
        return new ActivateProcessInstanceCmd(processInstance.getId());
    }
}

==> flowable-engine-6.3.0-sources.jar: org/flowable/engine/impl/cmd/ActivateProcessDefinitionCmd.java <==
/* Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.flowable.engine.impl.cmd;

import java.util.Date;

import org.flowable.engine.common.impl.db.SuspensionState;
import org.flowable.engine.impl.jobexecutor.TimerActivateProcessDefinitionHandler;
import org.flowable.engine.impl.persistence.entity.ProcessDefinitionEntity;
import org.flowable.engine.runtime.ProcessInstance;

/**
 * @author Daniel Meyer
 * @author Joram Barrez
 */
public class ActivateProcessDefinitionCmd extends AbstractSetProcessDefinitionStateCmd {

    public ActivateProcessDefinitionCmd(ProcessDefinitionEntity processDefinitionEntity, boolean includeProcessInstances, Date executionDate, String tenantId) {
        super(processDefinitionEntity, includeProcessInstances, executionDate, tenantId);
    }

    public ActivateProcessDefinitionCmd(String processDefinitionId, String processDefinitionKey, boolean includeProcessInstances, Date executionDate, String tenantId) {
        super(processDefinitionId, processDefinitionKey, includeProcessInstances, executionDate, tenantId);
    }

    @Override
    protected SuspensionState getProcessDefinitionSuspensionState() {
        return SuspensionState.ACTIVE;
    }

    @Override
    protected String getDelayedExecutionJobHandlerType() {
        return TimerActivateProcessDefinitionHandler.TYPE;
    }

    @Override
    protected AbstractSetProcessInstanceStateCmd getProcessInstanceChangeStateCmd(ProcessInstance processInstance) {
        return new ActivateProcessInstanceCmd(processInstance.getId());
    }
}
